# SetCohereApiKeyInput


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**key** | **str** |  | 

## Example

```python
from openapi_client.models.set_cohere_api_key_input import SetCohereApiKeyInput

# TODO update the JSON string below
json = "{}"
# create an instance of SetCohereApiKeyInput from a JSON string
set_cohere_api_key_input_instance = SetCohereApiKeyInput.from_json(json)
# print the JSON string representation of the object
print SetCohereApiKeyInput.to_json()

# convert the object into a dict
set_cohere_api_key_input_dict = set_cohere_api_key_input_instance.to_dict()
# create an instance of SetCohereApiKeyInput from a dict
set_cohere_api_key_input_form_dict = set_cohere_api_key_input.from_dict(set_cohere_api_key_input_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


